@@ -2,6 +2,9 @@
 
 static const R_CallMethodDef call_methods[] = {
   {"r_log_active", (DL_FUNC) &log_active, 0},
+  {"r_log_phase_get", (DL_FUNC) &log_phase_get, 0},
+  {"r_log_phase_reset", (DL_FUNC) &log_phase_reset, 0},
+  {"r_log_phase_set", (DL_FUNC) &log_phase_set, 1},
   {"r_log_print", (DL_FUNC) &log_print, 6},
   {"r_log_start", (DL_FUNC) &log_start, 6},
   {"r_log_stop", (DL_FUNC) &log_stop, 0},
