@@ -10,8 +10,11 @@ local({
   log_start(path = path, seconds = 0.5)
   temp <- log_active()
   Sys.sleep(2)
+  log_phase_set("different phase")
+  Sys.sleep(2)
   log_stop()
   temp <- log_active()
   temp <- log_read(path)
+  log_phase_reset()
   Sys.sleep(2)
 })
